HistoryItem class
HistoryItem class
This class is used to store the history of requests made to the server.
Constructors
- HistoryItem(String method, String path, dynamic data, dynamic queryParameters)
Properties
- data → dynamic
-
The data sent in the request.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → String
-
The HTTP method used in the request.
final
- path → String
-
The path of the request.
final
- queryParameters → dynamic
-
The query parameters of the request.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited